@@ -1,12 +1,12 @@
 single_word_regex = "^[A-Za-z0-9_-]+$"
 
-env_variable_dict = {
+env_variables = {
     "type": "object",
     "patternProperties": {single_word_regex: {"type": "string"}},
     "additionalProperties": False,
 }
 
-command_schema = {
+command_obj_schema = {
     "type": "object",
     "properties": {
         "cmd": {
@@ -15,12 +15,21 @@ command_schema = {
                 {"type": "array", "items": {"type": "string"}},
             ]
         },
-        "env": env_variable_dict,
+        "env": env_variables,
+        "description": {"type": "string"},
     },
     "required": ["cmd"],
     "additionalProperties": False,
 }
 
+command_schema = {
+    "anyOf": [
+        command_obj_schema,
+        {"type": "string"},
+        {"type": "array", "items": {"type": "string"}},
+    ]
+}
+
 schema = {
     "type": "object",
     "properties": {
@@ -29,7 +38,8 @@ schema = {
             "patternProperties": {single_word_regex: command_schema},
             "additionalProperties": False,
         },
-        "global_env": env_variable_dict,
+        "global_env": env_variables,
+        "shortcuts": env_variables,
     },
     "additionalProperties": False,
 }
